@@ -535,6 +535,8 @@
 #define	  SFF8636_DATE_MONTH_LEN		2
 #define	 SFF8636_DATE_DAY_OFFSET	0xD8
 #define	  SFF8636_DATE_DAY_LEN			2
+#define	 SFF8636_DATE_VENDOR_LOT_OFFSET 0xDA
+#define	  SFF8636_DATE_VENDOR_LOT_LEN		2
 
 /* Diagnostic Monitoring Type - 220 */
 #define	 SFF8636_DIAG_TYPE_OFFSET	0xDC
